NeptuneResultTracker
====================

.. currentmodule:: pykeen.trackers

.. autoclass:: NeptuneResultTracker
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~NeptuneResultTracker.log_metrics
      ~NeptuneResultTracker.log_params

   .. rubric:: Methods Documentation

   .. automethod:: log_metrics
   .. automethod:: log_params
